@@ -1,4 +1,4 @@
-from src.common_microservices.messages import Messages
+from common_structure_microservices.messages import Messages
 
 
 def response(data=[], message=Messages.SUCCESSFUL_MESSAGE, status=True):
